var parse = require('./parse')
var setMonth = require('./set_month')

/**
 * @category Quarter Helpers
 * @summary Set the year quarter.
 *
 * @description
 * Set the year quarter to the given date.
 *
 * @param {Date|String|Number} date to be changed
 * @param {Number} quarter of the new date
 * @returns {Date} new date with the quarter setted
 *
 * @example set second quarter to date 2 July 2014
 * var result = setQuarter(new Date(2014, 6, 2), 2)
 * //=> Wed Apr 02 2014 00:00:00
 */
var setQuarter = function(dirtyDate, quarter) {
  var date = parse(dirtyDate)
  var oldQuarter = Math.floor(date.getMonth() / 3) + 1
  var diff = quarter - oldQuarter
  return setMonth(date, date.getMonth() + diff * 3)
}

module.exports = setQuarter

